========
Modules
========

ehrcorral.ehrcorral
-------------------

Herd
^^^^

.. autoclass:: ehrcorral.ehrcorral.Herd
   :members:

Record
^^^^^^

.. autoclass:: ehrcorral.ehrcorral.Record
   :members:

Profile
^^^^^^^

.. autoclass:: ehrcorral.ehrcorral.Profile
   :member-order: bysource

gen_record()
^^^^^^^^^^^^

.. autofunction:: ehrcorral.ehrcorral.gen_record

compress()
^^^^^^^^^^

.. autofunction:: ehrcorral.ehrcorral.compress

ehrcorral.measures
------------------

record_similarity()
^^^^^^^^^^^^^^^^^^^

.. autofunction:: ehrcorral.measures.record_similarity

get_forename_similarity()
^^^^^^^^^^^^^^^^^^^^^^^^^

.. autofunction:: ehrcorral.measures.get_forename_similarity

extract_forename_similarity_info()
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. autofunction:: ehrcorral.measures.extract_forename_similarity_info

get_surname_similarity()
^^^^^^^^^^^^^^^^^^^^^^^^

.. autofunction:: ehrcorral.measures.get_surname_similarity

extract_surname_similarity_info()
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. autofunction:: ehrcorral.measures.extract_surname_similarity_info

get_address_similarity()
^^^^^^^^^^^^^^^^^^^^^^^^

.. autofunction:: ehrcorral.measures.get_address_similarity

clean_address()
^^^^^^^^^^^^^^^

.. autofunction:: ehrcorral.measures.clean_address

get_post_code_similarity()
^^^^^^^^^^^^^^^^^^^^^^^^^^

.. autofunction:: ehrcorral.measures.get_post_code_similarity

get_sex_similarity()
^^^^^^^^^^^^^^^^^^^^

.. autofunction:: ehrcorral.measures.get_sex_similarity


get_dob_similarity()
^^^^^^^^^^^^^^^^^^^^

.. autofunction:: ehrcorral.measures.get_dob_similarity

get_id_similarity()
^^^^^^^^^^^^^^^^^^^

.. autofunction:: ehrcorral.measures.get_id_similarity
